@@ -77,14 +77,14 @@ class VerifyToken:
         """
         per_status_this = 0
         # 查询redis中当前用户的权限集合
-        per_set_redis_info = self.redis_connect.get_(
-            self.uid + center_name_this + permission_name_this)
+        redis_key = self.uid + center_name_this + permission_name_this
+        per_set_redis_info = self.redis_connect.get_(redis_key)
         if per_set_redis_info:
             per_status_this = int(per_set_redis_info)
         if per_status_this == 0:
             handle_abnormal(
-                message='无 "{0}-{1}" 的访问权限({2})'.format(
-                    center_name_this, permission_name_this, per_set_redis_info),
+                message='无 "{0}-{1}" 的访问权限({2}={3})'.format(
+                    center_name_this, permission_name_this, redis_key, per_set_redis_info),
                 status=401,
             )
         return per_status_this
